@@ -57,10 +57,10 @@ from sphinx_toolbox.cache import cache  # noqa: F401
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "3.0.0"
+__version__: str = "3.1.0"
 __email__: str = "dominic@davis-foster.co.uk"
 
-__all__ = ["setup"]
+__all__ = ("setup", )
 
 
 def setup(app: Sphinx) -> "utils.SphinxExtMetadata":
