@@ -165,10 +165,10 @@ API Reference
 #
 
 # stdlib
-import os
 import re
+from os.path import join as joinpath
 from textwrap import dedent
-from typing import Any, Optional, cast
+from typing import Any, List, Optional, cast
 
 # 3rd party
 import sphinx
@@ -189,11 +189,11 @@ from sphinx.util.nodes import process_only_nodes
 from sphinx.writers.latex import LaTeXTranslator, LaTeXWriter
 
 # this package
-from sphinx_toolbox.utils import Config
+from sphinx_toolbox.utils import Config, SphinxExtMetadata, metadata_add_version
 
 _ = BuildEnvironment
 
-__all__ = [
+__all__ = (
 		"use_package",
 		"visit_footnote",
 		"depart_footnote",
@@ -206,7 +206,7 @@ __all__ = [
 		"better_header_layout",
 		"configure",
 		"setup",
-		]
+		)
 
 footmisc_symbols = ['0', *Footnotes.symbols]
 # footmisc_symbols = ['0', '*', '†', '‡', '§', '¶', '‖', "**", "††", "‡‡"]
@@ -265,8 +265,8 @@ def use_package(package: str, config: Config, *args: str, **kwargs: str) -> None
 
 	:param package:
 	:param config:
-	:param \*args:
-	:param \*\*kwargs:
+	:param \*args: Passed as options to the LaTeX package.
+	:param \*\*kwargs: Passed as named options to the LaTeX package.
 	"""
 
 	options: DelimitedList[str] = DelimitedList()
@@ -297,7 +297,7 @@ class SamepageDirective(SphinxDirective):
 
 	has_content = True
 
-	def run(self):
+	def run(self) -> List[nodes.Node]:
 		"""
 		Process the content of the directive.
 		"""
@@ -324,7 +324,7 @@ class ClearPageDirective(SphinxDirective):
 
 	has_content = True
 
-	def run(self):
+	def run(self) -> List[nodes.Node]:
 		"""
 		Process the content of the directive.
 		"""
@@ -347,7 +347,7 @@ class ClearDoublePageDirective(SphinxDirective):
 
 	has_content = True
 
-	def run(self):
+	def run(self) -> List[nodes.Node]:
 		"""
 		Process the content of the directive.
 		"""
@@ -366,7 +366,7 @@ class VSpaceDirective(SphinxDirective):
 
 	required_arguments = 1  # the space
 
-	def run(self):
+	def run(self) -> List[nodes.Node]:
 		"""
 		Process the content of the directive.
 		"""
@@ -391,7 +391,7 @@ class LaTeXDomain(Domain):
 			}
 
 
-def replace_unknown_unicode(app: Sphinx, exception: Optional[Exception] = None):
+def replace_unknown_unicode(app: Sphinx, exception: Optional[Exception] = None) -> None:
 	r"""
 	Replaces certain unknown unicode characters in the Sphinx LaTeX output with the best equivalents.
 
@@ -543,7 +543,7 @@ class PatchedLaTeXBuilder(LaTeXBuilder):
 			if len(entry) > 5:
 				toctree_only = entry[5]
 			destination = SphinxFileOutput(
-					destination_path=os.path.join(self.outdir, targetname),
+					destination_path=joinpath(self.outdir, targetname),
 					encoding="utf-8",
 					overwrite_if_changed=True
 					)
@@ -572,6 +572,7 @@ class PatchedLaTeXBuilder(LaTeXBuilder):
 					self.update_context()
 
 			with progress_message(__("writing")):
+				# pylint: disable=loop-invariant-statement
 				docsettings._author = author
 				docsettings._title = title
 				docsettings._contentsname = doctree["contentsname"]
@@ -581,9 +582,10 @@ class PatchedLaTeXBuilder(LaTeXBuilder):
 				doctree.settings = docsettings
 				docwriter.theme = theme
 				docwriter.write(doctree, destination)
+				# pylint: enable=loop-invariant-statement
 
 
-def configure(app: Sphinx, config: Config):
+def configure(app: Sphinx, config: Config) -> None:
 	"""
 	Configure :mod:`sphinx_toolbox.latex`.
 
@@ -602,7 +604,8 @@ def configure(app: Sphinx, config: Config):
 		config.latex_elements["preamble"] = f"{latex_preamble}\n{command_string}"
 
 
-def setup(app: Sphinx):
+@metadata_add_version
+def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.latex`.
 
@@ -622,3 +625,5 @@ def setup(app: Sphinx):
 	app.add_builder(PatchedLaTeXBuilder, override=True)
 
 	app.connect("config-inited", configure)
+
+	return {}
