@@ -69,19 +69,18 @@ This module monkeypatches in that behaviour.
 from typing import Dict, List, Type
 
 # 3rd party
-import autodocsumm  # type: ignore
+import autodocsumm  # type: ignore[import]
 import sphinx.ext.autodoc.directive
 from docutils.utils import assemble_option_dict
 from sphinx.application import Sphinx
-from sphinx.config import Config
 from sphinx.errors import ExtensionError
 from sphinx.ext.autodoc import Documenter, Options
 
 # this package
 import sphinx_toolbox
-from sphinx_toolbox.utils import SphinxExtMetadata
+from sphinx_toolbox.utils import Config, SphinxExtMetadata
 
-__all__ = ["process_documenter_options", "setup"]
+__all__ = ("process_documenter_options", "setup")
 
 
 def process_documenter_options(
@@ -104,6 +103,7 @@ def process_documenter_options(
 			negated = options.pop("no-" + name, True) is None
 
 			if name in config.autodoc_default_options and not negated:
+				# pylint: disable=loop-invariant-statement
 				default_value = config.autodoc_default_options[name]
 				existing_value = options.get(name, None)
 				values: List[str] = [v for v in [default_value, existing_value] if v not in {None, True, False}]
@@ -112,6 +112,7 @@ def process_documenter_options(
 					options[name] = ','.join(values)
 				else:
 					options[name] = None  # pragma: no cover
+				# pylint: enable=loop-invariant-statement
 
 	return Options(assemble_option_dict(options.items(), documenter.option_spec))
 
@@ -129,7 +130,7 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 				"must be loaded before 'sphinx.ext.autodoc'."
 				)
 
-	sphinx.ext.autodoc.directive.process_documenter_options = process_documenter_options
+	sphinx.ext.autodoc.directive.process_documenter_options = process_documenter_options  # type: ignore[assignment]
 	autodocsumm.process_documenter_options = process_documenter_options
 
 	app.setup_extension("sphinx.ext.autodoc")
