@@ -114,11 +114,11 @@ API Reference
 import inspect
 import itertools
 import json
-import operator
 import re
 import sys
 import types
 from contextlib import suppress
+from operator import itemgetter
 from tempfile import TemporaryDirectory
 from types import FunctionType, ModuleType
 from typing import (
@@ -200,7 +200,7 @@ except ImportError:
 		return _annotations.compiler_flag == CO_FUTURE_ANNOTATIONS
 
 
-__all__ = [
+__all__ = (
 		"ObjectAlias",
 		"Module",
 		"Function",
@@ -217,10 +217,9 @@ __all__ = [
 		"backfill_type_hints",
 		"load_args",
 		"split_type_comment_args",
-		"builder_ready",
 		"default_preprocessors",
 		"Preprocessor",
-		]
+		)
 
 get_annotation_module = sphinx_autodoc_typehints.get_annotation_module
 get_annotation_class_name = sphinx_autodoc_typehints.get_annotation_class_name
@@ -228,11 +227,10 @@ get_annotation_args = sphinx_autodoc_typehints.get_annotation_args
 backfill_type_hints = sphinx_autodoc_typehints.backfill_type_hints
 load_args = sphinx_autodoc_typehints.load_args
 split_type_comment_args = sphinx_autodoc_typehints.split_type_comment_args
-builder_ready = sphinx_autodoc_typehints.builder_ready
 
 
 # Demonstration of module default argument in signature
-def serialise(obj: Any, library=json) -> str:
+def serialise(obj: Any, library=json) -> str:  # noqa: MAN001
 	"""
 	Serialise an object into a JSON string.
 
@@ -300,7 +298,7 @@ class Class(ObjectAlias):
 	_alias_type = "class"
 
 
-def format_annotation(annotation, fully_qualified: bool = False) -> str:
+def format_annotation(annotation: Any, fully_qualified: bool = False) -> str:
 	"""
 	Format a type annotation.
 
@@ -464,17 +462,20 @@ def preprocess_function_defaults(obj: Callable) -> Tuple[Optional[inspect.Signat
 		return None, []
 
 	parameters = []
+	preprocessor_list = default_preprocessors
 
 	for param in signature.parameters.values():
 		default = param.default
 
+		# pylint: disable=dotted-import-in-loop
 		if default is not inspect.Parameter.empty:
-			for check, preprocessor in default_preprocessors:
+			for check, preprocessor in preprocessor_list:
 				if check(default):
 					default = preprocessor(default)
 					break
 
 		parameters.append(param.replace(annotation=inspect.Parameter.empty, default=default))
+		# pylint: enable=dotted-import-in-loop
 
 	return signature, parameters
 
@@ -503,12 +504,13 @@ def preprocess_class_defaults(
 		return init, None, []
 
 	parameters = []
+	preprocessor_list = default_preprocessors
 
 	for argname, param in signature.parameters.items():
 		default = param.default
 
 		if default is not inspect.Parameter.empty:
-			for check, preprocessor in default_preprocessors:
+			for check, preprocessor in preprocessor_list:
 				if check(default):
 					default = preprocessor(default)
 					break
@@ -526,7 +528,7 @@ def preprocess_class_defaults(
 	return init, signature, parameters
 
 
-def process_signature(
+def process_signature(  # noqa: MAN001
 		app: Sphinx,
 		what: str,
 		name: str,
@@ -698,17 +700,24 @@ def process_docstring(
 
 	original_obj = obj
 
-	for hook, priority in sorted(docstring_hooks, key=operator.itemgetter(1)):
+	for hook, priority in sorted(docstring_hooks, key=itemgetter(1)):
 		obj = hook(obj)
 
 	if callable(obj):
 		obj = inspect.unwrap(obj)
 		type_hints = get_all_type_hints(obj, name, original_obj)
+		signature_params = inspect.signature(obj).parameters
 
 		for argname, annotation in type_hints.items():
 			if argname == "return":
 				continue  # this is handled separately later
 
+			# Ensure *args and **kwargs have *s
+			if signature_params[argname].kind == 2:  # *args
+				argname = f"\\*{argname}"
+			elif signature_params[argname].kind == 4:  # **kwargs
+				argname = f"\\*\\*{argname}"
+
 			argname = escape_trailing__(argname)
 
 			formatted_annotation = format_annotation(
@@ -767,7 +776,7 @@ def process_docstring(
 					lines.insert(insert_index, f":rtype: {formatted_annotation}")
 
 
-def _class_get_type_hints(obj, globalns=None, localns=None):
+def _class_get_type_hints(obj, globalns=None, localns=None):  # noqa: MAN001,MAN002
 	"""
 	Return type hints for an object.
 
@@ -785,7 +794,7 @@ def _class_get_type_hints(obj, globalns=None, localns=None):
 
 	while True:
 
-		try:
+		try:  # pylint: disable=R8203
 			return get_type_hints(obj.__init__, localns=localns, globalns=globalns)
 		except NameError:
 			if not mro_stack:
@@ -796,7 +805,7 @@ def _class_get_type_hints(obj, globalns=None, localns=None):
 			localns = {**sys.modules[klasse.__module__].__dict__, **localns}
 
 
-def get_all_type_hints(obj: Any, name: str, original_obj) -> Dict[str, Any]:
+def get_all_type_hints(obj: Any, name: str, original_obj: Any) -> Dict[str, Any]:
 	"""
 	Returns the resolved type hints for the given objects.
 
@@ -805,7 +814,7 @@ def get_all_type_hints(obj: Any, name: str, original_obj) -> Dict[str, Any]:
 	:param original_obj: The original object, before the class if ``obj`` is its ``__init__`` method.
 	"""
 
-	def log(exc):
+	def log(exc: Exception) -> None:
 		sat_logger.warning(
 				'Cannot resolve forward reference in type annotations of "%s": %s',
 				name,
