@@ -60,13 +60,11 @@ from domdf_python_tools.doctools import prettify_docstrings
 from sphinx.addnodes import desc_content
 from sphinx.application import Sphinx
 from sphinx.environment import BuildEnvironment
-from sphinx.errors import PycodeError
 from sphinx.ext.autodoc import Documenter, logger
 from sphinx.locale import __
-from sphinx.pycode import ModuleAnalyzer
 from typing_extensions import TypedDict
 
-__all__ = [
+__all__ = (
 		"add_nbsp_substitution",
 		"allow_subclass_add",
 		"baseclass_is_private",
@@ -91,7 +89,7 @@ __all__ = [
 		"unknown_module_warning",
 		"untyped_param_regex",
 		"add_fallback_css_class",
-		]
+		)
 
 #: Instance of :class:`apeye.requests_url.RequestsURL` that points to the GitHub website.
 GITHUB_COM: RequestsURL = RequestsURL("https://github.com")
@@ -296,7 +294,7 @@ def get_first_matching(
 		if not condition(default):
 			raise ValueError("The condition must evaluate to True for the default value.")
 
-		iterable = [*iterable, default]
+		iterable = (*iterable, default)
 
 	for match in iterable:
 		if condition(match):
@@ -374,7 +372,7 @@ class SphinxExtMetadata(TypedDict, total=False):
 	"""
 
 
-SetupFunc = Callable[[Sphinx], Optional["SphinxExtMetadata"]]
+SetupFunc = Callable[[Sphinx], Optional[SphinxExtMetadata]]
 """
 Type annotation for Sphinx extensions' ``setup`` functions.
 
@@ -400,7 +398,7 @@ def unknown_module_warning(documenter: Documenter) -> None:
 	logger.warning(msg % documenter.name, type="autodoc")
 
 
-def filter_members_warning(member, exception: Exception) -> None:
+def filter_members_warning(member: Any, exception: Exception) -> None:
 	"""
 	Log a warning when filtering members.
 
@@ -486,7 +484,7 @@ def parse_parameters(lines: List[str], tab_size: int = 8) -> Tuple[Dict[str, Par
 	pre_output: List[str] = []
 	post_output: List[str] = []
 
-	def add_empty(param_name: str):
+	def add_empty(param_name: str) -> None:
 		if param_name not in params:
 			params[param_name] = {"doc": [], "type": ''}
 
@@ -496,9 +494,11 @@ def parse_parameters(lines: List[str], tab_size: int = 8) -> Tuple[Dict[str, Par
 			post_output.append(line)
 			continue
 
+		# pylint: disable=loop-global-usage
 		typed_m = typed_param_regex.match(line)
 		untyped_m = untyped_param_regex.match(line)
 		type_only_m = typed_flag_regex.match(line)
+		# pylint: enable=loop-global-usage
 
 		if typed_m:
 			last_arg = typed_m.group(3).strip()
@@ -539,7 +539,7 @@ def is_namedtuple(obj: Any) -> bool:
 	return isinstance(obj, type) and issubclass(obj, tuple) and hasattr(obj, "_fields")
 
 
-def allow_subclass_add(app: Sphinx, *documenters: Type[Documenter]):
+def allow_subclass_add(app: Sphinx, *documenters: Type[Documenter]) -> None:
 	"""
 	Add the given autodocumenters, but only if a subclass of it is not already registered.
 
@@ -580,7 +580,7 @@ def metadata_add_version(func: SetupFunc) -> SetupFunc:
 	"""  # noqa: D400
 
 	@functools.wraps(func)
-	def wrapper(app: Sphinx):
+	def wrapper(app: Sphinx) -> SphinxExtMetadata:
 
 		# this package
 		from sphinx_toolbox import __version__
@@ -621,7 +621,9 @@ _OBJTYPES_CSS_FALLBACKS = {
 # Copyright (c) 2021 Franz Wöllert
 
 
-def add_fallback_css_class(objtypes_css_fallbacks: Dict[str, str]):
+def add_fallback_css_class(
+		objtypes_css_fallbacks: Dict[str, str]
+		) -> Callable[[Sphinx, str, str, desc_content], None]:
 	"""
 	Registers a transform which will edit the CSS classes of documented objects based on their ``objtype``.
 
@@ -647,7 +649,7 @@ def add_fallback_css_class(objtypes_css_fallbacks: Dict[str, str]):
 			domain: str,
 			objtype: str,
 			contentnode: desc_content,
-			):
+			) -> None:
 
 		if objtype not in objtypes_css_fallbacks:
 			return
